@@ -14,7 +14,7 @@ import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataP
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataTypeProperties;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnTypeCodeProperties;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.LocaleTypeProperties;
-import org.gcube.portlets.user.td.expressionwidget.client.properties.TabResourceProperties;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.TabResourcePropertiesCombo;
 import org.gcube.portlets.user.td.expressionwidget.client.resources.ExpressionResources;
 import org.gcube.portlets.user.td.expressionwidget.client.rpc.ExpressionServiceAsync;
 import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnDataTypeElement;
@@ -326,8 +326,8 @@ public class AddColumnPanel extends FramedPanel implements
 		comboLocaleTypeLabel = new FieldLabel(comboLocaleType, "Locale");
 
 		// comboDimensionType
-		TabResourceProperties propsDimensionType = GWT
-				.create(TabResourceProperties.class);
+		TabResourcePropertiesCombo propsDimensionType = GWT
+				.create(TabResourcePropertiesCombo.class);
 		ListStore<TabResource> storeComboDimensionType = new ListStore<TabResource>(
 				propsDimensionType.id());
 
